# Print an optspec for argparse to handle cmd's options that are independent of any subcommand.
function __fish_jellytool_global_optspecs
	string join \n h/help V/version
end

function __fish_jellytool_needs_command
	# Figure out if the current invocation already has a command.
	set -l cmd (commandline -opc)
	set -e cmd[1]
	argparse -s (__fish_jellytool_global_optspecs) -- $cmd 2>/dev/null
	or return
	if set -q argv[1]
		# Also print the command, so this can be used to figure out what it is.
		echo $argv[1]
		return 1
	end
	return 0
end

function __fish_jellytool_using_subcommand
	set -l cmd (__fish_jellytool_needs_command)
	test -z "$cmd"
	and return 1
	contains -- $cmd[1] $argv
end

complete -c jellytool -n "__fish_jellytool_needs_command" -s h -l help -d 'Print help'
complete -c jellytool -n "__fish_jellytool_needs_command" -s V -l version -d 'Print version'
complete -c jellytool -n "__fish_jellytool_needs_command" -f -a "add" -d 'Interactive wizard for renaming files'
complete -c jellytool -n "__fish_jellytool_needs_command" -f -a "migrate" -d 'Migrate the database by export or import to JSON'
complete -c jellytool -n "__fish_jellytool_needs_command" -f -a "reimport" -d 'Issue a reimport via the API'
complete -c jellytool -n "__fish_jellytool_needs_command" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c jellytool -n "__fish_jellytool_using_subcommand add" -s h -l help -d 'Print help'
complete -c jellytool -n "__fish_jellytool_using_subcommand migrate" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c jellytool -n "__fish_jellytool_using_subcommand reimport" -l hostname -d 'Custom hostname, the config\'s is used by default' -r
complete -c jellytool -n "__fish_jellytool_using_subcommand reimport" -l no-tls -d 'Disable TLS. Dont use this'
complete -c jellytool -n "__fish_jellytool_using_subcommand reimport" -l no-incremental -d 'Perform full import'
complete -c jellytool -n "__fish_jellytool_using_subcommand reimport" -s h -l help -d 'Print help'
complete -c jellytool -n "__fish_jellytool_using_subcommand help; and not __fish_seen_subcommand_from add migrate reimport help" -f -a "add" -d 'Interactive wizard for renaming files'
complete -c jellytool -n "__fish_jellytool_using_subcommand help; and not __fish_seen_subcommand_from add migrate reimport help" -f -a "migrate" -d 'Migrate the database by export or import to JSON'
complete -c jellytool -n "__fish_jellytool_using_subcommand help; and not __fish_seen_subcommand_from add migrate reimport help" -f -a "reimport" -d 'Issue a reimport via the API'
complete -c jellytool -n "__fish_jellytool_using_subcommand help; and not __fish_seen_subcommand_from add migrate reimport help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
